@@ -1,32 +1,40 @@
-import datetime
-
 import os
+import datetime
+import threading
 
 
 class Logger:
+    _log_file = None
+
     def __init__(self, debug: bool = False, prefix: str = '', dir: str = os.path.join('.', 'logs')) -> None:
         self.debug = debug
         if self.debug:
-            filename = f'{prefix}_{self._get_timestamp()}.log'
-            if not os.path.exists(dir):
-                os.makedirs(dir)
-            self.log_file = os.path.join(dir, f'{filename}')
-            with open(self.log_file, 'w', encoding='utf-8'):
+            if Logger._log_file is None:
+                timestamp = self._get_timestamp()
+                filename = f'{prefix}_{timestamp}.log'
+                if not os.path.exists(dir):
+                    os.makedirs(dir)
+                Logger._log_file = os.path.join(dir, filename)
+
+            with open(Logger._log_file, 'a', encoding='utf-8'):
                 pass
 
+            self.lock = threading.Lock()
+
     def log(self, message: str, level: str = 'info'):
         time_str = self._get_timestamp("%H:%M:%S")
         log = f"[Qase][{time_str}][{level}] {message}\n"
         print(log)
         if self.debug:
-            with open(self.log_file, 'a', encoding='utf-8') as f:
-                f.write(log)
+            with self.lock:
+                with open(Logger._log_file, 'a', encoding='utf-8') as f:
+                    f.write(log)
 
     def log_debug(self, message: str):
         if self.debug:
             self.log(message, 'debug')
 
     @staticmethod
-    def _get_timestamp(fmt: str = "%Y%m%d_%H_%M_%S"):
+    def _get_timestamp(fmt: str = "%Y%m%d"):
         now = datetime.datetime.now()
         return now.strftime(fmt)
