@@ -1,4 +1,4 @@
-from .result import Result, Field
+from .result import Result, InternalResult, Field
 from .run import Run
 from .attachment import Attachment
 from .relation import Relation
@@ -12,5 +12,6 @@ __all__ = [
     Relation,
     Step,
     Runtime,
-    Field
+    Field,
+    InternalResult
 ]
